{{- define "lib.statefulset" }}
---
apiVersion: apps/v1
kind: StatefulSet
metadata:
  name: {{ include "lib.fullname" . }}
  namespace: {{ .Values.namespace }}
  labels:
    {{- include "lib.labels" . | nindent 4 }}
spec:
  persistentVolumeClaimRetentionPolicy:
    whenDeleted: Retain
    whenScaled: Retain
  replicas: {{ .Values.controller.replicas }}
  selector:
    matchLabels:
      {{- include "lib.selectorLabels" . | nindent 6 }}
  template:
    metadata:
      {{- with .Values.controller.annotations }}
      annotations:
        {{- toYaml . | nindent 8 }}
      {{- end }}
      labels:
        {{- include "lib.labels" . | nindent 8 }}
        {{- with .Values.controller.labels }}
        {{- toYaml . | nindent 8 }}
        {{- end }}
    spec:
      {{- with .Values.imagePullSecrets }}
      imagePullSecrets:
        {{- toYaml . | nindent 8 }}
      {{- end }}
      serviceAccountName: {{ include "lib.serviceAccountName" . }}
      securityContext:
        {{- toYaml .Values.controller.podSecurityContext | nindent 8 }}
      containers:
        - name: {{ .Chart.Name }}
          securityContext:
            {{- toYaml .Values.controller.securityContext | nindent 12 }}
          image: "{{ .Values.image.repository }}:{{ .Values.image.tag | default .Chart.AppVersion }}"
          imagePullPolicy: {{ .Values.image.pullPolicy }}
          ports:
          {{- range $name, $values := .Values.service -}}
          {{- if $values.enabled -}}
          {{- range $k, $v := $values.ports }}
            - name: {{ $k }}
              containerPort: {{ $v.targetPort | default $v.port }}
          {{- end -}}
          {{- end -}}
          {{- end }}
          env:
            {{- include "lib.environmentVariables" . | default "[]" | nindent 12 }}
          {{- with .Values.livenessProbe }}
          livenessProbe:
            {{- toYaml . | nindent 12 }}
          {{- end }}
          {{- with .Values.readinessProbe }}
          readinessProbe:
            {{- toYaml . | nindent 12 }}
          {{- end }}
          {{- with .Values.resources }}
          resources:
            {{- toYaml . | nindent 12 }}
          {{- end }}
          volumeMounts:
            {{- range $i, $values := .Values.volumeClaimTemplates }}
            - name: {{ $values.name }}
              mountPath: {{ $values.mountPath }}
            {{- end }}
      {{- with .Values.nodeSelector }}
      nodeSelector:
        {{- toYaml . | nindent 8 }}
      {{- end }}
      {{- with .Values.affinity }}
      affinity:
        {{- toYaml . | nindent 8 }}
      {{- end }}
      {{- with .Values.tolerations }}
      tolerations:
        {{- toYaml . | nindent 8 }}
      {{- end }}
  volumeClaimTemplates:
  {{- range $i, $values := .Values.volumeClaimTemplates }}
    - metadata:
        name: {{ $values.name }}
      spec:
        accessModes:
          -  {{ required (printf "accessMode is required for volumeClaimTemplate %v" $values.name) $values.accessMode  | quote }}
        storageClassName: {{ required (printf "storageClassName is required for volumeClaimTemplate %v" $values.name) $values.storageClassName  | quote }}
        resources:
          requests:
            storage: {{ required (printf "size is required for volumeClaimTemplate %v" $values.name) $values.size | quote }}
  {{- end }}
{{- end -}}
